package com.ruoyi.dxp.mapper;

import java.util.List;
import com.ruoyi.dxp.domain.Database;

/**
 * 数据源Mapper接口
 *
 * @author jy
 * @date 2022-11-15
 */
public interface DatabaseMapper
{
    /**
     * 查询数据源
     *
     * @param id 数据源主键
     * @return 数据源
     */
    public Database selectDatabaseById(Long id);

    /**
     * 查询数据源列表
     *
     * @param database 数据源
     * @return 数据源集合
     */
    public List<Database> selectDatabaseList(Database database);

    /**
     * 新增数据源
     *
     * @param database 数据源
     * @return 结果
     */
    public int insertDatabase(Database database);

    /**
     * 修改数据源
     *
     * @param database 数据源
     * @return 结果
     */
    public int updateDatabase(Database database);

    /**
     * 删除数据源
     *
     * @param id 数据源主键
     * @return 结果
     */
    public int deleteDatabaseById(Long id);

    /**
     * 批量删除数据源
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDatabaseByIds(Long[] ids);
}
